[ARVADOS-DEV] created: 2f56fdaf3a039ee87d264933fe1306c2642f81fe

git at public.curoverse.com git at public.curoverse.com
Wed Jun 24 13:59:21 EDT 2015


        at  2f56fdaf3a039ee87d264933fe1306c2642f81fe (commit)


commit 2f56fdaf3a039ee87d264933fe1306c2642f81fe
Author: Brett Smith <brett at curoverse.com>
Date:   Wed Jun 24 13:54:02 2015 -0400

    6388: Remove version munging from Python package builds.
    
    This code was added to accommodate version numbers that did *not*
    comply with PEP 440.  We've since fixed those, and they only include
    alphanumerics and dots, so we don't need to munge them.

diff --git a/jenkins/run-build-packages.sh b/jenkins/run-build-packages.sh
index 65515c8..7cece07 100755
--- a/jenkins/run-build-packages.sh
+++ b/jenkins/run-build-packages.sh
@@ -557,23 +557,17 @@ fpm_build_and_scp $GOPATH/bin/crunchstat=/usr/bin/crunchstat crunchstat 'Curover
 # whip up a patch and send it upstream, but that will be for another day. Ward,
 # 2014-05-15
 cd $WORKSPACE/debs
-# Python version numbering is obscure. Strip dashes and replace them with dots
-# to match our other version numbers. Cf. commit 4afcb8c, compliance with PEP-440.
-fpm_build_and_scp $WORKSPACE/sdk/python python-arvados-python-client 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2 }' $WORKSPACE/sdk/python/arvados_python_client.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados Python SDK" --depends=python2.7
+fpm_build_and_scp $WORKSPACE/sdk/python python-arvados-python-client 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){print $2}' $WORKSPACE/sdk/python/arvados_python_client.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados Python SDK" --depends=python2.7
 
 # The FUSE driver
 # Please see comment about --no-python-fix-name above; we stay consistent and do
 # not omit the python- prefix first.
 cd $WORKSPACE/debs
-# Python version numbering is obscure. Strip dashes and replace them with dots
-# to match our other version numbers. Cf. commit 4afcb8c, compliance with PEP-440.
-fpm_build_and_scp $WORKSPACE/services/fuse python-arvados-fuse 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2 }' $WORKSPACE/services/fuse/arvados_fuse.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Keep FUSE driver" --depends=python2.7
+fpm_build_and_scp $WORKSPACE/services/fuse python-arvados-fuse 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){print $2}' $WORKSPACE/services/fuse/arvados_fuse.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Keep FUSE driver" --depends=python2.7
 
 # The node manager
 cd $WORKSPACE/debs
-# Python version numbering is obscure. Strip dashes and replace them with dots
-# to match our other version numbers. Cf. commit 4afcb8c, compliance with PEP-440.
-fpm_build_and_scp $WORKSPACE/services/nodemanager arvados-node-manager 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2}' $WORKSPACE/services/nodemanager/arvados_node_manager.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados node manager" --depends=python2.7
+fpm_build_and_scp $WORKSPACE/services/nodemanager arvados-node-manager 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){print $2}' $WORKSPACE/services/nodemanager/arvados_node_manager.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados node manager" --depends=python2.7
 
 # The Docker image cleaner
 cd $WORKSPACE/debs

commit aac6af892c9bbaeb791d62ed7470a80713e66650
Author: Brett Smith <brett at curoverse.com>
Date:   Wed Jun 24 13:51:09 2015 -0400

    6388: run-build-packages records python2.7 dependency where needed.

diff --git a/jenkins/run-build-packages.sh b/jenkins/run-build-packages.sh
index e0584c4..5b2ad29 100755
--- a/jenkins/run-build-packages.sh
+++ b/jenkins/run-build-packages.sh
@@ -19,8 +19,8 @@ Options:
     Build api server and workbench packages with vendor/bundle included
 --debug
     Output debug information (default: false)
---format
-    Package format (default: deb)
+--target
+    Distribution to build packages for (default: debian7)
 
 WORKSPACE=path         Path to the Arvados source tree to build packages from
 
@@ -32,10 +32,10 @@ CALL_FREIGHT=0
 DEBUG=0
 UPLOAD=0
 BUILD_BUNDLE_PACKAGES=0
-FORMAT=deb
+TARGET=debian7
 
 PARSEDOPTS=$(getopt --name "$0" --longoptions \
-    help,upload,scp-user:,scp-host:,apt-server:,build-bundle-packages,debug,format: \
+    help,upload,scp-user:,scp-host:,apt-server:,build-bundle-packages,debug,target: \
     -- "" "$@")
 if [ $? -ne 0 ]; then
     exit 1
@@ -55,8 +55,8 @@ while [ $# -gt 0 ]; do
         --scp-host|--apt-server)
             SCPHOST="$2"; shift
             ;;
-        --format)
-            FORMAT="$2"; shift
+        --target)
+            TARGET="$2"; shift
             ;;
         --debug)
             DEBUG=1
@@ -86,7 +86,36 @@ if [[ "$UPLOAD" != '0' && ("$SCPUSER" == '' || "$SCPHOST" == '') ]]; then
   exit 1
 fi
 
-# Sanity check
+declare -a PYTHON_BACKPORTS PYTHON3_BACKPORTS
+
+case "$TARGET" in
+    debian7)
+        FORMAT=deb
+        FPM_OUTDIR=tmp
+        REPO_UPDATE_CMD='freight add *deb apt/wheezy && freight cache && rm -f *deb'
+        PYTHON_BACKPORTS=(python-gflags pyvcf google-api-python-client \
+            oauth2client pyasn1 pyasn1-modules rsa uritemplate httplib2 ws4py \
+            virtualenv pykka apache-libcloud requests six pyexecjs jsonschema \
+            ciso8601 pycrypto backports.ssl_match_hostname)
+        PYTHON3_BACKPORTS=(docker-py six requests)
+        ;;
+    centos6)
+        FORMAT=rpm
+        FPM_OUTDIR=rpm
+        REPO_UPDATE_CMD='mv *rpm /var/www/rpm.arvados.org/CentOS/6/os/x86_64/ && createrepo /var/www/rpm.arvados.org/CentOS/6/os/x86_64/'
+        PYTHON_BACKPORTS=(python-gflags pyvcf google-api-python-client \
+            oauth2client pyasn1 pyasn1-modules rsa uritemplate httplib2 ws4py \
+            virtualenv pykka apache-libcloud requests six pyexecjs jsonschema \
+            ciso8601 pycrypto backports.ssl_match_hostname)
+        PYTHON3_BACKPORTS=(docker-py six requests)
+        ;;
+    *)
+        echo -e "$0: Unknown target '$TARGET'.\n" >&2
+        exit 1
+        ;;
+esac
+
+
 if ! [[ -n "$WORKSPACE" ]]; then
   echo >&2 "$helpmessage"
   echo >&2
@@ -252,11 +281,7 @@ fpm_verify_and_scp () {
         echo "Error building package for $1:\n $FPM_RESULTS"
       else
         if [[ "$UPLOAD" != 0 ]]; then
-          if [[ "$FORMAT" == 'deb' ]]; then
-            scp -P2222 $FPM_PACKAGE_NAME $SCPUSER@$SCPHOST:tmp/
-          else
-            scp -P2222 $FPM_PACKAGE_NAME $SCPUSER@$SCPHOST:rpm/
-          fi
+          scp -P2222 $FPM_PACKAGE_NAME $SCPUSER@$SCPHOST:$FPM_OUTDIR/
           CALL_FREIGHT=1
         fi
       fi
@@ -546,15 +571,12 @@ cd $WORKSPACE/debs
 fpm_build_and_scp $WORKSPACE/services/dockercleaner arvados-docker-cleaner 'Curoverse, Inc.' 'python3' "$(awk '($1 == "Version:"){print $2}' $WORKSPACE/services/dockercleaner/arvados_docker_cleaner.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados Docker image cleaner"
 
 # A few dependencies
-for deppkg in python-gflags pyvcf google-api-python-client oauth2client \
-      pyasn1 pyasn1-modules rsa uritemplate httplib2 ws4py virtualenv \
-      pykka apache-libcloud requests six pyexecjs jsonschema ciso8601 \
-      pycrypto backports.ssl_match_hostname; do
+for deppkg in "${PYTHON_BACKPORTS[@]}"; do
     fpm_build_and_scp "$deppkg"
 done
 
 # Python 3 dependencies
-for deppkg in docker-py six requests; do
+for deppkg in "${PYTHON3_BACKPORTS[@]}"; do
     # The empty string is the vendor argument: these aren't Curoverse software.
     fpm_build_and_scp "$deppkg" "python3-$deppkg" "" python3
 done
@@ -689,11 +711,11 @@ fpm_verify_and_scp $FPM_EXIT_CODE $FPM_RESULTS
 
 # Finally, publish the packages, if necessary
 if [[ "$UPLOAD" != 0 && "$CALL_FREIGHT" != 0 ]]; then
-  if [[ "$FORMAT" == 'deb' ]]; then
-    ssh -p2222 $SCPUSER@$SCPHOST -t "cd tmp && ls -laF *deb && freight add *deb apt/wheezy && freight cache && rm -f *deb"
-  else
-    ssh -p2222 $SCPUSER@$SCPHOST -t "cd rpm && ls -laF *rpm && mv *rpm /var/www/rpm.arvados.org/CentOS/6/os/x86_64/ && createrepo /var/www/rpm.arvados.org/CentOS/6/os/x86_64/"
-  fi
+  ssh -p2222 $SCPUSER@$SCPHOST -t bash - <<EOF
+if [ -n "\$(find -name "$FPM_OUTDIR/*.$FORMAT" -print -quit)" ]; then
+    cd "$FPM_OUTDIR" && $REPO_UPDATE_CMD
+fi
+EOF
 else
   if [[ "$UPLOAD" != 0 ]]; then
     echo "No new packages generated. No freight run necessary."

commit f0d1f9935eadd303d6b160ae9c349398f6691bd9
Author: Brett Smith <brett at curoverse.com>
Date:   Tue Jun 23 12:10:54 2015 -0400

    6388: Remove Debianisms from run-build-packages.
    
    Make sure function and variable names don't refer to Debian when they
    can also be used for Red Hat.

diff --git a/jenkins/run-build-packages.sh b/jenkins/run-build-packages.sh
index 2e797bf..e0584c4 100755
--- a/jenkins/run-build-packages.sh
+++ b/jenkins/run-build-packages.sh
@@ -12,9 +12,9 @@ Options:
 --upload
     Upload packages (default: false)
 --scp-user USERNAME
-    Scp user for apt server (only required when --upload is specified)
---apt-server HOSTNAME
-    Apt server hostname (only required when --upload is specified)
+    scp user for repository server (only required when --upload is specified)
+--scp-host HOSTNAME
+    scp host for repository server (only required when --upload is specified)
 --build-bundle-packages  (default: false)
     Build api server and workbench packages with vendor/bundle included
 --debug
@@ -34,23 +34,29 @@ UPLOAD=0
 BUILD_BUNDLE_PACKAGES=0
 FORMAT=deb
 
-while [[ -n "$1" ]]
-do
-    arg="$1"; shift
-    case "$arg" in
+PARSEDOPTS=$(getopt --name "$0" --longoptions \
+    help,upload,scp-user:,scp-host:,apt-server:,build-bundle-packages,debug,format: \
+    -- "" "$@")
+if [ $? -ne 0 ]; then
+    exit 1
+fi
+
+eval set -- "$PARSEDOPTS"
+while [ $# -gt 0 ]; do
+    case "$1" in
         --help)
             echo >&2 "$helpmessage"
             echo >&2
             exit 1
             ;;
         --scp-user)
-            APTUSER="$1"; shift
+            SCPUSER="$2"; shift
             ;;
-        --apt-server)
-            APTSERVER="$1"; shift
+        --scp-host|--apt-server)
+            SCPHOST="$2"; shift
             ;;
         --format)
-            FORMAT="$1"; shift
+            FORMAT="$2"; shift
             ;;
         --debug)
             DEBUG=1
@@ -61,18 +67,21 @@ do
         --build-bundle-packages)
             BUILD_BUNDLE_PACKAGES=1
             ;;
-        *)
-            echo >&2 "$0: Unrecognized option: '$arg'. Try: $0 --help"
-            exit 1
+        --)
+            if [ $# -gt 1 ]; then
+                echo >&2 "$0: unrecognized argument '$2'. Try: $0 --help"
+                exit 1
+            fi
             ;;
     esac
+    shift
 done
 
 # Sanity checks
-if [[ "$UPLOAD" != '0' && ("$APTUSER" == '' || "$APTSERVER" == '') ]]; then
+if [[ "$UPLOAD" != '0' && ("$SCPUSER" == '' || "$SCPHOST" == '') ]]; then
   echo >&2 "$helpmessage"
   echo >&2
-  echo >&2 "Error: please specify --scp-user and --apt-server if --upload is set"
+  echo >&2 "Error: please specify --scp-user and --scp-host if --upload is set"
   echo >&2
   exit 1
 fi
@@ -158,7 +167,7 @@ handle_python_package () {
 }
 
 # Build debs for everything
-build_and_scp_deb () {
+fpm_build_and_scp () {
   # The package source.  Depending on the source type, this can be a
   # path, or the name of the package in an upstream repository (e.g.,
   # pip).
@@ -217,11 +226,11 @@ build_and_scp_deb () {
   FPM_RESULTS=$("${COMMAND_ARR[@]}")
   FPM_EXIT_CODE=$?
 
-  verify_and_scp_deb $FPM_EXIT_CODE $FPM_RESULTS
+  fpm_verify_and_scp $FPM_EXIT_CODE $FPM_RESULTS
 }
 
 # verify build results and scp debs, if needed
-verify_and_scp_deb () {
+fpm_verify_and_scp () {
   FPM_EXIT_CODE=$1
   shift
   FPM_RESULTS=$@
@@ -244,9 +253,9 @@ verify_and_scp_deb () {
       else
         if [[ "$UPLOAD" != 0 ]]; then
           if [[ "$FORMAT" == 'deb' ]]; then
-            scp -P2222 $FPM_PACKAGE_NAME $APTUSER@$APTSERVER:tmp/
+            scp -P2222 $FPM_PACKAGE_NAME $SCPUSER@$SCPHOST:tmp/
           else
-            scp -P2222 $FPM_PACKAGE_NAME $APTUSER@$APTSERVER:rpm/
+            scp -P2222 $FPM_PACKAGE_NAME $SCPUSER@$SCPHOST:rpm/
           fi
           CALL_FREIGHT=1
         fi
@@ -298,7 +307,7 @@ rm -rf install
 
 perl Makefile.PL >"$PERL_OUT" && \
     make install PREFIX=install INSTALLDIRS=perl >"$PERL_OUT" && \
-    build_and_scp_deb install/=/usr libarvados-perl "Curoverse, Inc." dir \
+    fpm_build_and_scp install/=/usr libarvados-perl "Curoverse, Inc." dir \
       "$(version_from_git)"
 
 # Ruby gems
@@ -335,16 +344,16 @@ if [[ "$?" != "0" ]]; then
     # -q appears to be broken in gem version 2.2.2
     gem build arvados.gemspec -q >/dev/null 2>&1
   fi
-  
+
   if [[ "$UPLOAD" != 0 ]]; then
     # publish new gem
     gem push arvados-*gem
   fi
-  
-  build_and_scp_deb arvados-*.gem "" "Curoverse, Inc." gem "" \
+
+  fpm_build_and_scp arvados-*.gem "" "Curoverse, Inc." gem "" \
       --prefix "$FPM_GEM_PREFIX"
 fi
-  
+
 # Build arvados-cli GEM
 cd "$WORKSPACE"
 cd sdk/cli
@@ -359,14 +368,14 @@ gem search arvados-cli -r -a |grep -q $ARVADOS_GEM_VERSION
 if [[ "$?" != "0" ]]; then
   # clean up old gems
   rm -f arvados-cli*gem
-  
+
   if [[ "$DEBUG" != 0 ]]; then
     gem build arvados-cli.gemspec
   else
     # -q appears to be broken in gem version 2.2.2
     gem build arvados-cli.gemspec -q >/dev/null
   fi
-  
+
   if [[ "$UPLOAD" != 0 ]]; then
     # publish new gem
     gem push arvados-cli*gem
@@ -427,7 +436,7 @@ git log --format=format:%H -n1 . > git-commit.version
 cd "$WORKSPACE"
 PKG_VERSION=$(version_from_git)
 cd $WORKSPACE/debs
-build_and_scp_deb $WORKSPACE/src-build-dir/=/usr/local/arvados/src arvados-src 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--exclude=usr/local/arvados/src/.git" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=The Arvados source code" "--architecture=all"
+fpm_build_and_scp $WORKSPACE/src-build-dir/=/usr/local/arvados/src arvados-src 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--exclude=usr/local/arvados/src/.git" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=The Arvados source code" "--architecture=all"
 
 # clean up, check out master and step away from detached-head state
 cd "$WORKSPACE/src-build-dir"
@@ -447,7 +456,7 @@ cd "$GOPATH/src/git.curoverse.com/arvados.git/services/keepstore"
 PKG_VERSION=$(version_from_git)
 go get "git.curoverse.com/arvados.git/services/keepstore"
 cd $WORKSPACE/debs
-build_and_scp_deb $GOPATH/bin/keepstore=/usr/bin/keepstore keepstore 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=Keepstore is the Keep storage daemon, accessible to clients on the LAN"
+fpm_build_and_scp $GOPATH/bin/keepstore=/usr/bin/keepstore keepstore 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=Keepstore is the Keep storage daemon, accessible to clients on the LAN"
 
 # Get GO SDK version
 cd "$GOPATH/src/git.curoverse.com/arvados.git/sdk/go"
@@ -467,7 +476,7 @@ fi
 
 go get "git.curoverse.com/arvados.git/services/keepproxy"
 cd $WORKSPACE/debs
-build_and_scp_deb $GOPATH/bin/keepproxy=/usr/bin/keepproxy keepproxy 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=Keepproxy makes a Keep cluster accessible to clients that are not on the LAN"
+fpm_build_and_scp $GOPATH/bin/keepproxy=/usr/bin/keepproxy keepproxy 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=Keepproxy makes a Keep cluster accessible to clients that are not on the LAN"
 
 # datamanager
 cd "$GOPATH/src/git.curoverse.com/arvados.git/services/datamanager"
@@ -482,7 +491,7 @@ fi
 
 go get "git.curoverse.com/arvados.git/services/datamanager"
 cd $WORKSPACE/debs
-build_and_scp_deb $GOPATH/bin/datamanager=/usr/bin/arvados-data-manager arvados-data-manager 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=Datamanager ensures block replication levels, reports on disk usage and determines which blocks should be deleted when space is needed."
+fpm_build_and_scp $GOPATH/bin/datamanager=/usr/bin/arvados-data-manager arvados-data-manager 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=Datamanager ensures block replication levels, reports on disk usage and determines which blocks should be deleted when space is needed."
 
 # arv-git-httpd
 cd "$GOPATH/src/git.curoverse.com/arvados.git/services/arv-git-httpd"
@@ -497,14 +506,14 @@ fi
 
 go get "git.curoverse.com/arvados.git/services/arv-git-httpd"
 cd $WORKSPACE/debs
-build_and_scp_deb $GOPATH/bin/arv-git-httpd=/usr/bin/arvados-git-httpd arvados-git-httpd 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=Provides authenticated http access to Arvados-hosted git repositories."
+fpm_build_and_scp $GOPATH/bin/arv-git-httpd=/usr/bin/arvados-git-httpd arvados-git-httpd 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=Provides authenticated http access to Arvados-hosted git repositories."
 
 # crunchstat
 cd "$GOPATH/src/git.curoverse.com/arvados.git/services/crunchstat"
 PKG_VERSION=$(version_from_git)
 go get "git.curoverse.com/arvados.git/services/crunchstat"
 cd $WORKSPACE/debs
-build_and_scp_deb $GOPATH/bin/crunchstat=/usr/bin/crunchstat crunchstat 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=Crunchstat gathers cpu/memory/network statistics of running Crunch jobs"
+fpm_build_and_scp $GOPATH/bin/crunchstat=/usr/bin/crunchstat crunchstat 'Curoverse, Inc.' 'dir' "$PKG_VERSION" "--url=https://arvados.org" "--license=GNU Affero General Public License, version 3.0" "--description=Crunchstat gathers cpu/memory/network statistics of running Crunch jobs"
 
 # The Python SDK
 # Please resist the temptation to add --no-python-fix-name to the fpm call here
@@ -516,7 +525,7 @@ build_and_scp_deb $GOPATH/bin/crunchstat=/usr/bin/crunchstat crunchstat 'Curover
 cd $WORKSPACE/debs
 # Python version numbering is obscure. Strip dashes and replace them with dots
 # to match our other version numbers. Cf. commit 4afcb8c, compliance with PEP-440.
-build_and_scp_deb $WORKSPACE/sdk/python python-arvados-python-client 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2 }' $WORKSPACE/sdk/python/arvados_python_client.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados Python SDK"
+fpm_build_and_scp $WORKSPACE/sdk/python python-arvados-python-client 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2 }' $WORKSPACE/sdk/python/arvados_python_client.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados Python SDK"
 
 # The FUSE driver
 # Please see comment about --no-python-fix-name above; we stay consistent and do
@@ -524,30 +533,30 @@ build_and_scp_deb $WORKSPACE/sdk/python python-arvados-python-client 'Curoverse,
 cd $WORKSPACE/debs
 # Python version numbering is obscure. Strip dashes and replace them with dots
 # to match our other version numbers. Cf. commit 4afcb8c, compliance with PEP-440.
-build_and_scp_deb $WORKSPACE/services/fuse python-arvados-fuse 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2 }' $WORKSPACE/services/fuse/arvados_fuse.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Keep FUSE driver"
+fpm_build_and_scp $WORKSPACE/services/fuse python-arvados-fuse 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2 }' $WORKSPACE/services/fuse/arvados_fuse.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Keep FUSE driver"
 
 # The node manager
 cd $WORKSPACE/debs
 # Python version numbering is obscure. Strip dashes and replace them with dots
 # to match our other version numbers. Cf. commit 4afcb8c, compliance with PEP-440.
-build_and_scp_deb $WORKSPACE/services/nodemanager arvados-node-manager 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2}' $WORKSPACE/services/nodemanager/arvados_node_manager.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados node manager"
+fpm_build_and_scp $WORKSPACE/services/nodemanager arvados-node-manager 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2}' $WORKSPACE/services/nodemanager/arvados_node_manager.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados node manager"
 
 # The Docker image cleaner
 cd $WORKSPACE/debs
-build_and_scp_deb $WORKSPACE/services/dockercleaner arvados-docker-cleaner 'Curoverse, Inc.' 'python3' "$(awk '($1 == "Version:"){print $2}' $WORKSPACE/services/dockercleaner/arvados_docker_cleaner.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados Docker image cleaner"
+fpm_build_and_scp $WORKSPACE/services/dockercleaner arvados-docker-cleaner 'Curoverse, Inc.' 'python3' "$(awk '($1 == "Version:"){print $2}' $WORKSPACE/services/dockercleaner/arvados_docker_cleaner.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados Docker image cleaner"
 
 # A few dependencies
 for deppkg in python-gflags pyvcf google-api-python-client oauth2client \
       pyasn1 pyasn1-modules rsa uritemplate httplib2 ws4py virtualenv \
       pykka apache-libcloud requests six pyexecjs jsonschema ciso8601 \
       pycrypto backports.ssl_match_hostname; do
-    build_and_scp_deb "$deppkg"
+    fpm_build_and_scp "$deppkg"
 done
 
 # Python 3 dependencies
 for deppkg in docker-py six requests; do
     # The empty string is the vendor argument: these aren't Curoverse software.
-    build_and_scp_deb "$deppkg" "python3-$deppkg" "" python3
+    fpm_build_and_scp "$deppkg" "python3-$deppkg" "" python3
 done
 
 # Build the API server package
@@ -590,7 +599,7 @@ if [[ "$BUILD_BUNDLE_PACKAGES" != 0 ]]; then
 
   FPM_RESULTS=$("${COMMAND_ARR[@]}")
   FPM_EXIT_CODE=$?
-  verify_and_scp_deb $FPM_EXIT_CODE $FPM_RESULTS
+  fpm_verify_and_scp $FPM_EXIT_CODE $FPM_RESULTS
 fi
 
 # Build the 'bare' package without vendor/bundle.
@@ -604,7 +613,7 @@ fi
 
 FPM_RESULTS=$("${COMMAND_ARR[@]}")
 FPM_EXIT_CODE=$?
-verify_and_scp_deb $FPM_EXIT_CODE $FPM_RESULTS
+fpm_verify_and_scp $FPM_EXIT_CODE $FPM_RESULTS
 
 # API server package build done
 
@@ -659,7 +668,7 @@ if [[ "$BUILD_BUNDLE_PACKAGES" != 0 ]]; then
 
   FPM_RESULTS=$("${COMMAND_ARR[@]}")
   FPM_EXIT_CODE=$?
-  verify_and_scp_deb $FPM_EXIT_CODE $FPM_RESULTS
+  fpm_verify_and_scp $FPM_EXIT_CODE $FPM_RESULTS
 fi
 
 # Build the 'bare' package without vendor/bundle.
@@ -674,16 +683,16 @@ fi
 
 FPM_RESULTS=$("${COMMAND_ARR[@]}")
 FPM_EXIT_CODE=$?
-verify_and_scp_deb $FPM_EXIT_CODE $FPM_RESULTS
+fpm_verify_and_scp $FPM_EXIT_CODE $FPM_RESULTS
 
 # Workbench package build done
 
 # Finally, publish the packages, if necessary
 if [[ "$UPLOAD" != 0 && "$CALL_FREIGHT" != 0 ]]; then
   if [[ "$FORMAT" == 'deb' ]]; then
-    ssh -p2222 $APTUSER@$APTSERVER -t "cd tmp && ls -laF *deb && freight add *deb apt/wheezy && freight cache && rm -f *deb"
+    ssh -p2222 $SCPUSER@$SCPHOST -t "cd tmp && ls -laF *deb && freight add *deb apt/wheezy && freight cache && rm -f *deb"
   else
-    ssh -p2222 $APTUSER@$APTSERVER -t "cd rpm && ls -laF *rpm && mv *rpm /var/www/rpm.arvados.org/CentOS/6/os/x86_64/ && createrepo /var/www/rpm.arvados.org/CentOS/6/os/x86_64/"
+    ssh -p2222 $SCPUSER@$SCPHOST -t "cd rpm && ls -laF *rpm && mv *rpm /var/www/rpm.arvados.org/CentOS/6/os/x86_64/ && createrepo /var/www/rpm.arvados.org/CentOS/6/os/x86_64/"
   fi
 else
   if [[ "$UPLOAD" != 0 ]]; then

-----------------------------------------------------------------------


hooks/post-receive
diff --git a/jenkins/run-build-packages.sh b/jenkins/run-build-packages.sh
index 5b2ad29..65515c8 100755
--- a/jenkins/run-build-packages.sh
+++ b/jenkins/run-build-packages.sh
@@ -216,14 +216,23 @@ fpm_build_and_scp () {
   VERSION=$1
   shift
 
-  # fpm does not actually support a python3 package type.  Instead we recognize
-  # it as a convenience shortcut to add several necessary arguments to
-  # fpm's command line later, after we're done handling positional arguments.
-  if [ "python3" = "$PACKAGE_TYPE" ]; then
-      PACKAGE_TYPE=python
-      set -- "$@" --python-bin python3 --python-easyinstall easy_install3 \
-          --python-package-name-prefix python3 --depends python3
-  fi
+  case "$PACKAGE_TYPE" in
+      python)
+          # All Arvados Python2 packages depend on Python 2.7.
+          # Make sure we build with that for consistency.
+          set -- "$@" --python-bin python2.7 \
+              --python-easyinstall easy_install-2.7
+          ;;
+      python3)
+          # fpm does not actually support a python3 package type.  Instead
+          # we recognize it as a convenience shortcut to add several
+          # necessary arguments to fpm's command line later, after we're
+          # done handling positional arguments.
+          PACKAGE_TYPE=python
+          set -- "$@" --python-bin python3 --python-easyinstall easy_install3 \
+              --python-package-name-prefix python3 --depends python3
+          ;;
+  esac
 
   declare -a COMMAND_ARR=("fpm" "--maintainer=Ward Vandewege <ward at curoverse.com>" "-s" "$PACKAGE_TYPE" "-t" "$FORMAT" "-x" "usr/local/lib/python2.7/dist-packages/tests")
 
@@ -550,7 +559,7 @@ fpm_build_and_scp $GOPATH/bin/crunchstat=/usr/bin/crunchstat crunchstat 'Curover
 cd $WORKSPACE/debs
 # Python version numbering is obscure. Strip dashes and replace them with dots
 # to match our other version numbers. Cf. commit 4afcb8c, compliance with PEP-440.
-fpm_build_and_scp $WORKSPACE/sdk/python python-arvados-python-client 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2 }' $WORKSPACE/sdk/python/arvados_python_client.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados Python SDK"
+fpm_build_and_scp $WORKSPACE/sdk/python python-arvados-python-client 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2 }' $WORKSPACE/sdk/python/arvados_python_client.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados Python SDK" --depends=python2.7
 
 # The FUSE driver
 # Please see comment about --no-python-fix-name above; we stay consistent and do
@@ -558,13 +567,13 @@ fpm_build_and_scp $WORKSPACE/sdk/python python-arvados-python-client 'Curoverse,
 cd $WORKSPACE/debs
 # Python version numbering is obscure. Strip dashes and replace them with dots
 # to match our other version numbers. Cf. commit 4afcb8c, compliance with PEP-440.
-fpm_build_and_scp $WORKSPACE/services/fuse python-arvados-fuse 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2 }' $WORKSPACE/services/fuse/arvados_fuse.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Keep FUSE driver"
+fpm_build_and_scp $WORKSPACE/services/fuse python-arvados-fuse 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2 }' $WORKSPACE/services/fuse/arvados_fuse.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Keep FUSE driver" --depends=python2.7
 
 # The node manager
 cd $WORKSPACE/debs
 # Python version numbering is obscure. Strip dashes and replace them with dots
 # to match our other version numbers. Cf. commit 4afcb8c, compliance with PEP-440.
-fpm_build_and_scp $WORKSPACE/services/nodemanager arvados-node-manager 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2}' $WORKSPACE/services/nodemanager/arvados_node_manager.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados node manager"
+fpm_build_and_scp $WORKSPACE/services/nodemanager arvados-node-manager 'Curoverse, Inc.' 'python' "$(awk '($1 == "Version:"){ gsub(/-/,".",$2); print $2}' $WORKSPACE/services/nodemanager/arvados_node_manager.egg-info/PKG-INFO)" "--url=https://arvados.org" "--description=The Arvados node manager" --depends=python2.7
 
 # The Docker image cleaner
 cd $WORKSPACE/debs

commit 0e13d045f78e1c78c9f2be3012c6bf06bf1ea5bd
Author: Brett Smith <brett at curoverse.com>
Date:   Wed Jun 24 13:24:20 2015 -0400

    6388: Add distro targets to run-build-packages.
    
    This will provide us a single mechanism to make sure that packages are
    built to run on a particular distribution: not just in terms of FPM's
    output format, but also repository location, backports required, etc.

-- 




More information about the arvados-commits mailing list